<?php
/**
 * Main Themify class
 * @package themify
 */
class Themify {
	/** Default sidebar layout
	 * @var string */
	public $layout;
	/** Default posts layout
	 * @var string */
	public $post_layout;
	
	public $hide_title;
	public $hide_meta;
	public $hide_date;
	public $hide_image;
	
	public $unlink_title;
	public $unlink_image;
	
	public $display_content = '';
	public $auto_featured_image;
	
	public $width = '';
	public $height = '';
	
	public $avatar_size = 96;
	public $page_navigation;
	public $posts_per_page;
	
	public $image_align = '';
	public $image_setting = '';
	
	public $page_id = '';
	public $page_image_width = 978;
	public $query_category = '';
	public $paged = '';
	public $allow_sorting = '';
	
	public $is_section = false;
	public $section_term = '';
	
	/////////////////////////////////////////////
	// Set Default Image Sizes 					
	/////////////////////////////////////////////
	
	// Default Index Layout
	static $content_width = 998;
	static $sidebar1_content_width = 670;
	
	// Default Single Post Layout
	static $single_content_width = 998;
	static $single_sidebar1_content_width = 670;
	
	// Default Single Image Size
	static $single_image_width = 998;
	static $single_image_height = 500;
	
	// Grid3
	static $grid3_width = 670;
	static $grid3_height = 300;
	
	// Grid2
	static $grid2_width = 670;
	static $grid2_height = 300;
	
	// List Post
	static $list_post_width = 998;
	static $list_post_height = 0;
	
	// Index Portfolio
	static $index_portfolio_image_width = 998;
	static $index_portfolio_image_height = 494;
	
	// Single Portfolio
	static $single_portfolio_image_width = 670;
	static $single_portfolio_image_height = 0;
	
	// Sorting Parameters
	public $order = 'DESC';
	public $orderby = 'date';

	function __construct() {
		
		///////////////////////////////////////////
		//Global options setup
		///////////////////////////////////////////
		$this->layout = themify_get('setting-default_layout');
		if($this->layout == '' ) $this->layout = 'sidebar1';
		
		$this->post_layout = themify_get('setting-default_post_layout');
		if($this->post_layout == '') $this->post_layout = 'list-post'; 
		
		$this->page_title = themify_get('setting-hide_page_title');
		$this->hide_title = themify_get('setting-default_post_title');
		$this->unlink_title = themify_get('setting-default_unlink_post_title');
		
		$this->hide_image = themify_get('setting-default_post_image');
		$this->unlink_image = themify_get('setting-default_unlink_post_image');
		$this->auto_featured_image = !themify_check('setting-auto_featured_image')? 'field_name=post_image, image, wp_thumb&' : '';
		$this->hide_page_image = themify_get( 'setting-hide_page_image' ) == 'yes' ? 'yes' : 'no';
		
		$this->hide_meta = themify_get('setting-default_post_meta');
		$this->hide_date = themify_get('setting-default_post_date');

		// Set Order & Order By parameters for post sorting
		$this->order = themify_check('setting-index_order')? themify_get('setting-index_order'): 'DESC';
		$this->orderby = themify_check('setting-index_orderby')? themify_get('setting-index_orderby'): 'date';
		
		$this->display_content = themify_get('setting-default_layout_display');
		$this->avatar_size = apply_filters('themify_author_box_avatar_size', 96);

		$this->posts_per_page = get_option('posts_per_page');
		
		add_action('template_redirect', array(&$this, 'template_redirect'));
	}

	function template_redirect() {
		
		$post_image_width = themify_get('image_width');
		$post_image_height = themify_get('image_height');

		if( is_singular() ) {
			$this->display_content = 'content';
		}

		if ( is_page() ) {
			$this->page_id = get_the_ID();
			$this->post_layout = (themify_get('layout') != "default" && themify_check('layout')) ?
									themify_get('layout') : themify_get('setting-default_post_layout');
			// set default post layout
			if($this->post_layout == '')
				$this->post_layout = 'list-post';
		}
		
		///////////////////////////////////////////
		// Setting image width, height
		///////////////////////////////////////////
		if($this->post_layout == 'grid3'):
		
			$this->width = self::$grid3_width;
			$this->height = self::$grid3_height;
		
		elseif($this->post_layout == 'grid2'):
		
			$this->width = self::$grid2_width;
			$this->height = self::$grid2_height;
			
		elseif($this->post_layout == 'list-post'):
		
			$this->width = self::$list_post_width;
			$this->height = self::$list_post_height;
		
		else:
					
			$this->width = self::$list_post_width;
			$this->height = self::$list_post_height;
			
		endif;
		
		if( is_page() ) {
			if(get_query_var('paged')):
				$this->paged = get_query_var('paged');
			elseif(get_query_var('page')):
				$this->paged = get_query_var('page');
			else:
				$this->paged = 1;
			endif;
			global $paged;
			$paged = $this->paged;
			
			// Query categories
			$this->query_category = themify_get('query_category');
			
			// Custom post type/taxonomy queries
			if('portfolio' == themify_get('_query_post_type')){
				$this->query_category = themify_get('_query_portfolio');
			}
			
			$this->layout = (themify_get('page_layout') != 'default' && themify_check('page_layout')) ? themify_get('page_layout') : themify_get('setting-default_page_layout');
			if($this->layout == '')
				$this->layout = 'sidebar1';
			
			$this->post_layout = (themify_get('layout') != 'default' && themify_check('layout')) ? themify_get('layout') : themify_get('setting-default_post_layout');
			if($this->post_layout == '')
				$this->post_layout = 'list-post';
			
			$this->page_title = (themify_get('hide_page_title') != 'default' && themify_check('hide_page_title')) ? themify_get('hide_page_title') : themify_get('setting-hide_page_title'); 
			$this->hide_title = themify_get('hide_title'); 
			$this->unlink_title = themify_get('unlink_title'); 
			$this->hide_image = themify_get('hide_image'); 
		    $this->unlink_image = themify_get('unlink_image'); 
			$this->hide_meta = themify_get('hide_meta'); 
			$this->hide_date = themify_get('hide_date'); 
			$this->display_content = themify_get('display_content');
			$this->post_image_width = themify_get('image_width'); 
			$this->post_image_height = themify_get('image_height'); 
			$this->page_navigation = themify_get('hide_navigation');
			if(themify_check('posts_per_page'))
				$this->posts_per_page = themify_get('posts_per_page');
			$this->order = (themify_get('order') && '' != themify_get('order')) ? themify_get('order') : (themify_check('setting-index_order') ? themify_get('setting-index_order') : 'DESC');
			$this->orderby = (themify_get('orderby') && '' != themify_get('orderby')) ? themify_get('orderby') : (themify_check('setting-index_orderby') ? themify_get('setting-index_orderby') : 'date');
			
			$this->allow_sorting = (themify_get('allow_sorting') != "default" && themify_check('allow_sorting')) ? themify_get('allow_sorting') : themify_get('setting-allow_sorting');
			
			if( '' != $post_image_height && '' != $post_image_width) {
				$this->width = $post_image_width;
				$this->height = $post_image_height;
			}
		}

		if( is_tax('portfolio-category') ){
			$pcpre = 'setting-default_portfolio_index_';
			$this->hide_title = themify_get($pcpre.'title')? 
				themify_get('setting-default_portfolio_index_title') : '';
			
			$this->unlink_title = themify_get($pcpre.'unlink_post_title')? 
				themify_get($pcpre.'unlink_post_title') : '';
			
			$this->hide_date = themify_get($pcpre.'post_date')? 
				themify_get($pcpre.'post_date') : '';
			
			$this->hide_meta = themify_get($pcpre.'post_meta')?
				themify_get($pcpre.'post_meta') : '';
			
			$this->display_content = themify_get($pcpre.'display')?
				themify_get($pcpre.'display') : 'none';
			
			$this->layout = themify_get($pcpre.'layout');
			if($this->layout == '')	$this->layout = 'sidebar-none'; 
			
			$this->post_layout = themify_get($pcpre.'post_layout');
			if($this->post_layout == '') $this->post_layout = 'grid3';
				
			$this->width = themify_check($pcpre.'image_post_width') ?
				themify_get($pcpre.'image_post_width'):	self::$index_portfolio_image_width;
			$this->height = themify_get($pcpre.'image_post_height') ?
				themify_get($pcpre.'image_post_height'): self::$index_portfolio_image_height;
		}

		if( is_single() || is_singular('portfolio') ) {
			$this->hide_title = (themify_get('hide_post_title') != 'default' && themify_check('hide_post_title')) ? themify_get('hide_post_title') : themify_get('setting-default_page_post_title');
			$this->unlink_title = (themify_get('unlink_post_title') != 'default' && themify_check('unlink_post_title')) ? themify_get('unlink_post_title') : themify_get('setting-default_page_unlink_post_title');
			$this->hide_date = (themify_get('hide_post_date') != 'default' && themify_check('hide_post_date')) ? themify_get('hide_post_date') : themify_get('setting-default_page_post_date');
			$this->hide_meta = (themify_get('hide_post_meta') != 'default' && themify_check('hide_post_meta')) ? themify_get('hide_post_meta') : themify_get('setting-default_page_post_meta');
			$this->hide_image = (themify_get('hide_post_image') != 'default' && themify_check('hide_post_image')) ? themify_get('hide_post_image') : themify_get('setting-default_page_post_image');
			$this->unlink_image = (themify_get('unlink_post_image') != 'default' && themify_check('unlink_post_image')) ? themify_get('unlink_post_image') : themify_get('setting-default_page_unlink_post_image');
			
			$post_image_width = themify_get('image_width');
			$post_image_height = themify_get('image_height');
			
			if( is_singular('portfolio') ){
				$this->hide_title = (themify_get('hide_post_title') != 'default' && themify_check('hide_post_title')) ? themify_get('hide_post_title') : themify_get('setting-default_portfolio_single_title');
				$this->unlink_title = (themify_get('unlink_post_title') != 'default' && themify_check('unlink_post_title')) ? themify_get('unlink_post_title') : themify_get('setting-default_portfolio_single_unlink_post_title');
				$this->hide_date = (themify_get('hide_post_date') != 'default' && themify_check('hide_post_date')) ? themify_get('hide_post_date') : themify_get('setting-default_portfolio_single_post_date');
				$this->hide_meta = (themify_get('hide_post_meta') != 'default' && themify_check('hide_post_meta')) ? themify_get('hide_post_meta') : themify_get('setting-default_portfolio_single_post_meta');
				
				$this->post_image_width = themify_check('setting-default_portfolio_single_image_post_width') ?
								themify_get('setting-default_portfolio_single_image_post_width'):
								self::$single_portfolio_image_width;
				$this->post_image_height = themify_get('setting-default_portfolio_single_image_post_height') ?
								themify_get('setting-default_portfolio_single_image_post_height'):
								self::$single_portfolio_image_height;
			}
			
			$default_layout = is_singular('portfolio')? themify_get('setting-default_portfolio_single_layout'): themify_get('setting-default_page_post_layout');
			
			$this->layout = (themify_get('layout') == 'sidebar-none'
							|| themify_get('layout') == 'sidebar1'
							|| themify_get('layout') == 'sidebar1 sidebar-left'
							|| themify_get('layout') == 'sidebar2') ?
								themify_get('layout') : $default_layout;
			 // set default layout
			 if($this->layout == '' && !is_singular('portfolio')) {
			 	$this->layout = 'sidebar1';
			 } elseif($this->layout == '' && is_singular('portfolio')) {
			 	$this->layout = 'sidebar-none';
			 }
			
			
			$this->display_content = '';			
			
			// Set Default Image Sizes for Single
			self::$content_width = self::$single_content_width;
			self::$sidebar1_content_width = self::$single_sidebar1_content_width;
			
			if ( '' === $post_image_width || is_null( $post_image_width ) ) {
				if ( is_singular( 'portfolio' ) ) {
					$this->width = themify_check('setting-default_portfolio_single_image_post_width') ?
								themify_get('setting-default_portfolio_single_image_post_width'):
								self::$single_portfolio_image_width;
				} else {
					$this->width  = self::$single_image_width;
				}
			} else {
				$this->width = $post_image_width;
			}
			if ( '' === $post_image_height || is_null( $post_image_height ) ) {
				if ( is_singular( 'portfolio' ) ) {
					$this->height = themify_get('setting-default_portfolio_single_image_post_height') ?
								themify_get('setting-default_portfolio_single_image_post_height'):
								self::$single_portfolio_image_height;
				} else {
					$this->height = self::$single_image_height;
				}
			} else {
				$this->height = $post_image_height;
			}
		}
		
		if($this->layout == 'sidebar1' || $this->layout == 'sidebar1 sidebar-left') {
			$ratio = $this->width / self::$content_width;
			$aspect = $this->height / $this->width;
			if(!is_singular('portfolio'))
				$this->width = round($ratio * self::$sidebar1_content_width);
			if($this->height != '' && $this->height != 0)
				$this->height = round($this->width * $aspect);
		}
		
		if(is_single() && $this->hide_image != 'yes') {
			$this->image_align = themify_get('setting-image_post_single_align');
			$this->image_setting = 'setting=image_post_single&';
		} elseif($this->query_category != '' && $this->hide_image != 'yes') {
			$this->image_align = '';
			$this->image_setting = '';
		} else {
			$this->image_align = themify_get('setting-image_post_align');
			$this->image_setting = 'setting=image_post&';
		}
	}
	
	/**
	 * Returns post category IDs concatenated in a string
	 * @param number Post ID
	 * @return string Category IDs
	 */
	public function get_categories_as_classes($post_id){
		$categories = wp_get_post_categories($post_id);
		$class = '';
		foreach($categories as $cat)
			$class .= ' cat-'.$cat;
		return $class;
	}
	
	public function get_post_color_class($post_id){
		$post_color_class = (themify_check('post_color') && themify_get('post_color') != 'default') ? themify_get('post_color') : 'default';
		
		if('default' == $post_color_class){
			$post_color_class = themify_get('setting-default_color')? themify_get('setting-default_color') : 'default';
		}
		return $post_color_class;
	}
	 	 
	 /**
	  * Returns category description
	  * @return string
	  */
	 function get_category_description(){
	 	$category_description = category_description();
		if ( !empty( $category_description ) ){
			return '<div class="category-description">' . $category_description . '</div>';
		}
	 }
	 
	 
	
	/**
	 * Returns URL in link field for Link Post Format
	 * @param string
	 * @return string
	 */
	function link_post_format($meta = 'link_url'){
		$link = themify_get($meta);
		if ($link == '')
			$link = get_permalink();
		return $link;
	}
	
	/**
	 * Returns post format or 'default'
	 * @return string
	 */
	function get_format_template(){
		$post_format = themify_get('post_format');
		
		if($post_format == 'quote' || has_post_format( 'quote' )) {
			return 'quote';
		} elseif($post_format == 'audio' || has_post_format( 'audio' )) {
			return 'audio';
		} elseif($post_format == 'video' || has_post_format( 'video' )) {
			return 'video';
		} else {
			return 'default';
		}
	}
	
	/**
	 * Outputs several classes for layout like colors, size and others
	 * @param bool Whether to echo or not
	 * @return string
	 */
	function extra_classes($echo = true){
		$classes = themify_check('_portfolio_color')? themify_get('_portfolio_color') : 'default';
		if('default' == $classes){
			$classes = themify_get('setting-default_portfolio_color')? themify_get('setting-default_portfolio_color') : 'default';
		}
		if($echo){
			echo $classes;
		} else {
			return $classes;
		}
	}

	/**
	 * Returns the image for the portfolio slider
	 * @param int $attachment_id Image attachment ID
	 * @param int $width Width of the returned image
	 * @param int $height Height of the returned image
	 * @param string $size Size of the returned image
	 * @return string
	 * @since 1.2.4
	 */
	function portfolio_image($attachment_id, $width, $height, $size = 'large') {
		$size = apply_filters( 'themify_portfolio_image_size', $size );
		if ( themify_check( 'setting-img_settings_use' ) ) {
			// Image Script is disabled, use WP image
			$html = wp_get_attachment_image( $attachment_id, $size );
		} else {
			// Image Script is enabled, use it to process image
			$img = wp_get_attachment_image_src($attachment_id, $size);
			$html = themify_get_image('ignore=true&src='.$img[0].'&w='.$width.'&h='.$height);
		}
		return apply_filters( 'themify_portfolio_image_html', $html, $attachment_id, $width, $height, $size );
	}
}

/**
 * Initializes Themify class
 */
function themify_global_options(){
	/**
	 * Themify initialization class
	 */
	global $themify;
	$themify = new Themify();
}
add_action( 'after_setup_theme','themify_global_options', 12 );

?>